==> moodle-1.4.3-pgsql.tgz: moodle/lang/fr/glossary.php <==
<?php // $Id$ 

$string['addcomment'] = 'Ajouter un commentaire';
$string['addentry'] = 'Ajouter un nouvel article';
$string['addingcomment'] = 'Ajout d\'un commentaire';
$string['aliases'] = 'Termes associs';
$string['allcategories'] = 'Toutes les catgories';
$string['allentries'] = 'Tout';
$string['allowcomments'] = 'Autoriser les commentaires';
$string['allowduplicatedentries'] = 'Autoriser les doublons';
$string['allowratings'] = 'Autoriser l\'valuation des articles';
$string['answer'] = 'Rponse';
$string['approve'] = 'Approuver';
$string['areyousuredelete'] = 'Voulez-vous vraiment supprimer cet article ?';
$string['areyousuredeletecomment'] = 'Voulez-vous vraiment supprimer ce commentaire ?';
$string['areyousureexport'] = 'Voulez-vous vraiment exporter cet article vers';
$string['ascending'] = '(ascendant)';
$string['attachment'] = 'Annexe';
$string['authorview'] = 'Consulter par auteur';
$string['back'] = 'Prcdent';
$string['cantinsertcat'] = 'Impossible d\'insrer la catgorie';
$string['cantinsertrec'] = 'Impossible d\'insrer l\'enregistrement';
$string['cantinsertrel'] = 'Impossible d\'insrer le lien catgorie-article';
$string['casesensitive'] = 'Cet article est sensible  la casse';
$string['categories'] = 'Catgories';
$string['category'] = 'Catgorie';
$string['categorydeleted'] = 'Catgorie supprime';
$string['categoryview'] = 'Consulter par catgorie';
$string['cnfallowcomments'] = 'Dfinit si un glossaire accepte par dfaut les commentaires sur les articles';
$string['cnfallowdupentries'] = 'Dfinit si un glossaire accepte par dfaut les doublons';
$string['cnfapprovalstatus'] = 'Dfinit le statut d\'approbation d\'un article propos par un tudiant';
$string['cnfcasesensitive'] = 'Dfinit si un article doit par dfaut correspondre exactement au texte cible (casse des caractres), quand il est li';
$string['cnfdefaulthook'] = 'Slectionne la slection  afficher par dfaut lors du premier affichage du glossaire';
$string['cnfdefaultmode'] = 'Slectionne le cadre  afficher par dfaut lors du premier affichage du glossaire';
$string['cnffullmatch'] = 'Dfinit si un article doit par dfaut correspondre mot pour mot au texte cible, quand il est li';
$string['cnflinkentry'] = 'Dfinit si un article est par dfaut automatiquement li';
$string['cnflinkglossaries'] = 'Dfinit si un glossaire doit par dfaut tre li';
$string['cnfrelatedview'] = 'Slectionne le format d\'affichage utilis pour les liens automatiques et l\'affichache des articles';
$string['cnfshowgroup'] = 'Indique si la coupure de groupe doit tre visible ou non';
$string['cnfsortkey']     = 'Slectionne la clef de tri par dfaut';
$string['cnfsortorder']   = 'Slectionne l\'ordre de tri par dfaut';
$string['cnfstudentcanpost'] = 'Dfinit si les tudiants peuvent par dfaut proposer des articles dans un glossaire ';
$string['comment'] = 'Commentaire';
$string['commentdeleted'] = 'Le commentaire a t effac.';
$string['comments'] = 'Commentaires';
$string['commentson'] = 'Commentaires activs';
$string['commentupdated'] = 'Le commentaire a t mis  jour.';
$string['concept'] = 'Concept';
$string['concepts'] = 'Concepts';
$string['configenablerssfeeds'] = 'Activation de l\'option des canaux RSS pour tous les glossaires. Il est en outre ncessaire d\'activer manuellement les canaux dans les rglages de chaque glossaire.';
$string['currentglossary'] = 'Glossaire actuel';
$string['dateview'] = 'Consulter par date';
$string['defaultapproval'] = 'Approbation par dfaut';
$string['definition'] = 'Dfinition';
$string['definitions'] = 'Dfinitions';
$string['deleteentry'] = 'Supprimer l\'article';
$string['deletingcomment'] = 'Suppression du commentaire';
$string['deletingnoneemptycategory'] = 'La suppression de cette catgorie ne supprimera pas les articles qu\'elle contient. Ceux-ci seront marques comme sans catgorie.';
$string['descending'] = '(descendant)';
$string['destination'] = 'Destination';
$string['displayformat'] = 'Format d\'affichage';
$string['displayformatcontinuous'] = 'Continu sans auteur';
$string['displayformatdictionary'] = 'Simple, style dictionnaire';
$string['displayformatencyclopedia'] = 'Encyclopdie';
$string['displayformatentrylist'] =  'Liste d\'articles';
$string['displayformatfaq'] = 'FAQ';
$string['displayformatfullwithauthor'] = 'Complet avec auteur';
$string['displayformatfullwithoutauthor'] = 'Complet sans auteur';
$string['displayformats'] = 'Formats d\'affichage';
$string['displayformatssetup'] = 'Rglages des formats d\'affichage';
$string['duplicateentry'] = 'Doublon';
$string['editalways'] = 'Toujours modifier';
$string['editcategories'] = 'Modifier les catgories';
$string['editentry'] = 'Modifier l\'article';
$string['editingcomment'] = 'Modification commentaire';
$string['entbypage'] = 'Articles affichs sur une page';
$string['entries'] = 'Articles';
$string['entrieswithoutcategory'] = 'Articles sans catgorie';
$string['entry'] = 'Article';
$string['entryalreadyexist'] = 'Cet article existe dj';
$string['entryapproved'] = 'Cet article a t approuv';
$string['entrydeleted'] = 'Article supprim';
$string['entryexported'] = 'Article export avec succs';
$string['entryishidden'] = '(Cet article est actuellement masque)';
$string['entryleveldefaultsettings'] = 'Rglages par dfaut des articles';
$string['entrysaved'] = 'Cet article a t enregistr';
$string['entryupdated'] = 'Cet article a t mis  jour';
$string['entryusedynalink'] = 'Cet article sera automatiquement li';
$string['explainaddentry'] = 'Ajout d\'un article au glossaire actuel.<br />Les champs concept et dfinition doivent obligatoirement tre remplis.';
$string['explainall'] = 'Afficher TOUS les articles sur une page';
$string['explainalphabet'] = 'Consultez le glossaire  l\'aide de cet index';
$string['explainexport'] = 'Un fichier a t gnr.<br />Tlchargez-le et conservez-le avec soin. Vous pourrez l\'importer quand vous voudrez dans ce cours ou dans un autre.';
$string['explainimport'] = 'Vous devez indiquer le fichier  importer et slectionner vos options.<br />Lancez votre requte et contrlez les rsultats.';
$string['explainspecial'] = 'Afficher les articles ne commenant pas par une lettre';
$string['exportedentry'] = 'Article export';
$string['exportedfile'] = 'Fichier export';
$string['exportentries'] = 'Exporter des articles';
$string['exportglossary'] = 'Exporter le glossaire';
$string['exporttomainglossary'] = 'Exporter vers le glossaire principal';
$string['filetoimport'] = 'Fichier  importer';
$string['fillfields'] = 'Les champs concept et dfinition sont obligatoires.';
$string['filtername'] = 'Liens automatiques des glossaires';
$string['fullmatch'] = 'Correspondance mot pour mot';
$string['globalglossary'] = 'Glossaire global';
$string['glossaryleveldefaultsettings'] = 'Rglages par dfaut des glossaires';
$string['glossarytype'] = 'Type de glossaire';
$string['glosssaryexported'] = 'Glossaire export.';
$string['importcategories'] = 'Importer les catgories';
$string['importedcategories'] = 'Catgories importes';
$string['importedentries'] = 'Articles imports';
$string['importentries'] = 'Importer des articles';
$string['isglobal'] = 'Ce glossaire est-il global ?';
$string['linkcategory'] = 'Lier automatiquement cette catgorie';
$string['mainglossary'] = 'Glossaire principal';
$string['maxtimehaspassed'] = 'Dsol ! la dure maximale pour la modification de ce commentaire ($a) est chue.';
$string['modulename'] = 'Glossaire';
$string['modulenameplural'] = 'Glossaires';
$string['newentries'] = 'Nouveaux articles du glossaire';
$string['newglossary'] = 'Nouveau glossaire';
$string['newglossarycreated'] = 'Nouveau glossaire cr.';
$string['newglossaryentries'] = 'Nouveaux articles du glossaire :';
$string['nocomment'] = 'Aucun commentaire trouv';
$string['nocomments'] = '(Aucun commentaire trouv sur cet article)';
$string['noconceptfound'] = 'Aucun concept, ni dfinition trouvs.';
$string['noentries'] = 'Aucun article trouv dans cette section';
$string['noentry'] = 'Aucune article trouv.';
$string['notcategorised'] = 'Sans catgorie';
$string['numberofentries'] = 'Nombre d\'articles';
$string['onebyline'] = '(une par ligne)';
$string['printerfriendly'] = 'Version pour impression';
$string['question'] = 'Question';
$string['rate'] = 'valuer';
$string['rating'] = 'Note';
$string['ratingeveryone'] = 'Tout le monde peut valuer les articles';
$string['ratingno'] = 'Pas de note';
$string['ratingonlyteachers'] = 'Seuls les $a peuvent valuer les articles';
$string['ratings'] = 'Notes';
$string['ratingssaved'] = 'Notes enregistres';
$string['ratingsuse'] = 'Utiliser les notes';
$string['ratingtime'] = 'Restreindre les notes aux articles entre les dates suivantes :';
$string['rejectedentries'] = 'Articles rejets';
$string['rejectionrpt'] = 'Rapport de rejet';
$string['rsssubscriberss'] = 'Affichage du canal RSS des concepts du glossaire  $a ';
$string['searchindefinition'] = 'Rechercher dans les dfinitions aussi';
$string['secondaryglossary'] = 'Glossaire secondaire';
$string['sendinratings'] = 'Envoyer mes dernires valuations';
$string['showall'] = 'Afficher le lien  Tout ';
$string['showalphabet'] = 'Afficher l\'alphabet';
$string['showspecial'] = 'Afficher le lien  Spcial ';
$string['sortby'] = 'Trier par';
$string['sortbycreation'] = 'Par date de cration';
$string['sortbylastupdate'] = 'Par date de mise  jour';
$string['sortchronogically'] = 'Trier chronologiquement ';
$string['special'] = 'Spcial';
$string['standardview'] = 'Consulter alphabtiquement';
$string['studentcanpost'] = 'Les tudiants peuvent ajouter des articles';
$string['totalentries'] = 'Nombre total d\'articles';
$string['usedynalink'] = 'Lier automatiquement les articles des glossaires';
$string['waitingapproval'] = 'En attente d\'approbation';
$string['warningstudentcapost'] = '(n\'est valable que si le glossaire n\'est pas principal)';
$string['withauthor'] = 'Concepts avec auteur';
$string['withoutauthor'] = 'Concepts sans auteur';
$string['writtenby'] = 'par';
$string['youarenottheauthor'] = 'vous n\'tes pas l\'auteur de ce commentaire. Vous ne pouvez donc pas le modifier.';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/fr/glossary.php <==
<?php // $Id$ 

$string['addcomment'] = 'Ajouter un commentaire';
$string['addentry'] = 'Ajouter un nouvel article';
$string['addingcomment'] = 'Ajout d\'un commentaire';
$string['aliases'] = 'Termes associs';
$string['allcategories'] = 'Toutes les catgories';
$string['allentries'] = 'Tout';
$string['allowcomments'] = 'Autoriser les commentaires';
$string['allowduplicatedentries'] = 'Autoriser les doublons';
$string['allowprintview'] = 'Autoriser l\'affichage pour impression';
$string['allowratings'] = 'Autoriser l\'valuation des articles';
$string['answer'] = 'Rponse';
$string['approve'] = 'Approuver';
$string['areyousuredelete'] = 'Voulez-vous vraiment supprimer cet article ?';
$string['areyousuredeletecomment'] = 'Voulez-vous vraiment supprimer ce commentaire ?';
$string['areyousureexport'] = 'Voulez-vous vraiment exporter cet article vers';
$string['ascending'] = '(ascendant)';
$string['attachment'] = 'Annexe';
$string['authorview'] = 'Consulter par auteur';
$string['back'] = 'Prcdent';
$string['cantinsertcat'] = 'Impossible d\'insrer la catgorie';
$string['cantinsertrec'] = 'Impossible d\'insrer l\'enregistrement';
$string['cantinsertrel'] = 'Impossible d\'insrer le lien catgorie-article';
$string['casesensitive'] = 'Article sensible  la casse';
$string['categories'] = 'Catgories';
$string['category'] = 'Catgorie';
$string['categorydeleted'] = 'Catgorie supprime';
$string['categoryview'] = 'Consulter par catgorie';
$string['cnfallowcomments'] = 'Dfinit si un glossaire accepte par dfaut les commentaires sur les articles';
$string['cnfallowdupentries'] = 'Dfinit si un glossaire accepte par dfaut les doublons';
$string['cnfapprovalstatus'] = 'Dfinit le statut d\'approbation d\'un article propos par un tudiant';
$string['cnfcasesensitive'] = 'Dfinit si un article doit par dfaut correspondre exactement au texte cible (casse des caractres), quand il est li';
$string['cnfdefaulthook'] = 'Dfinit la slection  afficher par dfaut lors du premier affichage du glossaire';
$string['cnfdefaultmode'] = 'Dfinit le cadre  afficher par dfaut lors du premier affichage du glossaire';
$string['cnffullmatch'] = 'Dfinit si un article doit par dfaut correspondre mot pour mot au texte cible, quand il est li';
$string['cnflinkentry'] = 'Dfinit si un article est par dfaut automatiquement li';
$string['cnflinkglossaries'] = 'Dfinit si un glossaire doit par dfaut tre li';
$string['cnfrelatedview'] = 'Dfinit le format d\'affichage utilis pour les liens automatiques et l\'affichache des articles';
$string['cnfshowgroup'] = 'Indique si la coupure de groupe doit tre visible ou non';
$string['cnfsortkey']     = 'Dfinit la clef de tri par dfaut';
$string['cnfsortorder']   = 'Dfinit l\'ordre de tri par dfaut';
$string['cnfstudentcanpost'] = 'Dfinit si les tudiants peuvent par dfaut proposer des articles dans un glossaire ';
$string['comment'] = 'Commentaire';
$string['commentdeleted'] = 'Le commentaire a t effac.';
$string['comments'] = 'Commentaires';
$string['commentson'] = 'Commentaires activs';
$string['commentupdated'] = 'Le commentaire a t mis  jour.';
$string['concept'] = 'Concept';
$string['concepts'] = 'Concepts';
$string['configenablerssfeeds'] = 'Activation de l\'option des canaux RSS pour tous les glossaires. Il est en outre ncessaire d\'activer manuellement les canaux dans les rglages de chaque glossaire.';
$string['currentglossary'] = 'Glossaire actuel';
$string['dateview'] = 'Consulter par date';
$string['defaultapproval'] = 'Approbation par dfaut';
$string['definition'] = 'Dfinition';
$string['definitions'] = 'Dfinitions';
$string['deleteentry'] = 'Supprimer l\'article';
$string['deletingcomment'] = 'Suppression du commentaire';
$string['deletingnoneemptycategory'] = 'La suppression de cette catgorie ne supprimera pas les articles qu\'elle contient. Ceux-ci seront marques comme sans catgorie.';
$string['descending'] = '(descendant)';
$string['destination'] = 'Destination';
$string['displayformat'] = 'Format d\'affichage';
$string['displayformatcontinuous'] = 'Continu sans auteur';
$string['displayformatdictionary'] = 'Simple, style dictionnaire';
$string['displayformatencyclopedia'] = 'Encyclopdie';
$string['displayformatentrylist'] =  'Liste d\'articles';
$string['displayformatfaq'] = 'FAQ';
$string['displayformatfullwithauthor'] = 'Complet avec auteur';
$string['displayformatfullwithoutauthor'] = 'Complet sans auteur';
$string['displayformats'] = 'Formats d\'affichage';
$string['displayformatssetup'] = 'Rglages des formats d\'affichage';
$string['duplicateentry'] = 'Doublon';
$string['editalways'] = 'Toujours modifiable';
$string['editcategories'] = 'Modifier les catgories';
$string['editentry'] = 'Modifier l\'article';
$string['editingcomment'] = 'Modification commentaire';
$string['entbypage'] = 'Articles affichs sur une page';
$string['entries'] = 'Articles';
$string['entrieswithoutcategory'] = 'Articles sans catgorie';
$string['entry'] = 'Article';
$string['entryalreadyexist'] = 'Cet article existe dj';
$string['entryapproved'] = 'Cet article a t approuv';
$string['entrydeleted'] = 'Article supprim';
$string['entryexported'] = 'Article export avec succs';
$string['entryishidden'] = '(Cet article est actuellement masqu)';
$string['entryleveldefaultsettings'] = 'Rglages par dfaut des articles';
$string['entrysaved'] = 'Cet article a t enregistr';
$string['entryupdated'] = 'Cet article a t mis  jour';
$string['entryusedynalink'] = 'Article li automatiquement';
$string['explainaddentry'] = 'Ajout d\'un article au glossaire actuel.<br />Les champs concept et dfinition doivent obligatoirement tre remplis.';
$string['explainall'] = 'Afficher TOUS les articles sur une page';
$string['explainalphabet'] = 'Consultez le glossaire  l\'aide de cet index';
$string['explainexport'] = 'Un fichier a t gnr.<br />Tlchargez-le et conservez-le avec soin. Vous pourrez l\'importer quand vous voudrez dans ce cours ou dans un autre.';
$string['explainimport'] = '<p>Vous devez indiquer le fichier  importer et slectionner vos options.</p><p>Lancez votre requte et contrlez les rsultats.</p>';
$string['explainspecial'] = 'Afficher les articles ne commenant pas par une lettre';
$string['exportedentry'] = 'Article export';
$string['exportedfile'] = 'Fichier export';
$string['exportentries'] = 'Exporter des articles';
$string['exportglossary'] = 'Exporter le glossaire';
$string['exporttomainglossary'] = 'Exporter vers le glossaire principal';
$string['filetoimport'] = 'Fichier  importer';
$string['fillfields'] = 'Les champs concept et dfinition sont obligatoires.';
$string['filtername'] = 'Liens automatiques des glossaires';
$string['fullmatch'] = 'Correspondance mot pour mot';
$string['globalglossary'] = 'Glossaire global';
$string['glossaryleveldefaultsettings'] = 'Rglages par dfaut des glossaires';
$string['glossarytype'] = 'Type de glossaire';
$string['glosssaryexported'] = 'Glossaire export.';
$string['importcategories'] = 'Importer les catgories';
$string['importedcategories'] = 'Catgories importes';
$string['importedentries'] = 'Articles imports';
$string['importentries'] = 'Importer des articles';
$string['isglobal'] = 'Glossaire global';
$string['linkcategory'] = 'Lier automatiquement cette catgorie';
$string['mainglossary'] = 'Glossaire principal';
$string['maxtimehaspassed'] = 'Dsol ! la dure maximale pour la modification de ce commentaire ($a) est chue.';
$string['modulename'] = 'Glossaire';
$string['modulenameplural'] = 'Glossaires';
$string['newentries'] = 'Nouveaux articles du glossaire';
$string['newglossary'] = 'Nouveau glossaire';
$string['newglossarycreated'] = 'Nouveau glossaire cr.';
$string['newglossaryentries'] = 'Nouveaux articles du glossaire :';
$string['nocomment'] = 'Aucun commentaire trouv';
$string['nocomments'] = '(Aucun commentaire trouv sur cet article)';
$string['noconceptfound'] = 'Aucun concept, ni dfinition trouvs.';
$string['noentries'] = 'Aucun article trouv dans cette section';
$string['noentry'] = 'Aucune article trouv.';
$string['notcategorised'] = 'Sans catgorie';
$string['numberofentries'] = 'Nombre d\'articles';
$string['onebyline'] = '(une par ligne)';
$string['printerfriendly'] = 'Version pour impression';
$string['printviewnotallowed'] = 'L\'affichage pour impression n\'est pas autoris';
$string['question'] = 'Question';
$string['rate'] = 'valuer';
$string['rating'] = 'Note';
$string['ratingeveryone'] = 'Tout le monde peut valuer les articles';
$string['ratingno'] = 'Pas de note';
$string['ratingonlyteachers'] = 'Seuls les $a peuvent valuer les articles';
$string['ratings'] = 'Notes';
$string['ratingssaved'] = 'Notes enregistres';
$string['ratingsuse'] = 'Utiliser les notes';
$string['ratingtime'] = 'Restreindre les notes aux articles entre les dates suivantes :';
$string['rejectedentries'] = 'Articles rejets';
$string['rejectionrpt'] = 'Rapport de rejet';
$string['rsssubscriberss'] = 'Affichage du canal RSS des concepts du glossaire  $a ';
$string['searchindefinition'] = 'Rechercher dans les dfinitions aussi';
$string['secondaryglossary'] = 'Glossaire secondaire';
$string['sendinratings'] = 'Envoyer mes dernires valuations';
$string['showall'] = 'Afficher le lien  Tout ';
$string['showalphabet'] = 'Afficher l\'alphabet';
$string['showspecial'] = 'Afficher le lien  Spcial ';
$string['sortby'] = 'Trier par';
$string['sortbycreation'] = 'Par date de cration';
$string['sortbylastupdate'] = 'Par date de mise  jour';
$string['sortchronogically'] = 'Trier chronologiquement ';
$string['special'] = 'Spcial';
$string['standardview'] = 'Consulter alphabtiquement';
$string['studentcanpost'] = 'Les tudiants peuvent ajouter des articles';
$string['totalentries'] = 'Nombre total d\'articles';
$string['usedynalink'] = 'Activer les liens automatiques';
$string['waitingapproval'] = 'En attente d\'approbation';
$string['warningstudentcapost'] = '(n\'est valable que si le glossaire n\'est pas principal)';
$string['withauthor'] = 'Concepts avec auteur';
$string['withoutauthor'] = 'Concepts sans auteur';
$string['writtenby'] = 'par';
$string['youarenottheauthor'] = 'vous n\'tes pas l\'auteur de ce commentaire. Vous ne pouvez donc pas le modifier.';

?>
